@@ -1,3 +1,18 @@
+# Copyright (C) 2020-2022 Koen Derks
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 #' Select a Statistical Audit Sample
 #'
 #' @description This function takes a data frame and performs statistical selection according to one of four algorithms: fixed interval sampling, cell sampling, random sampling, and modified sieve sampling. Selection is done on the level of two possible sampling units: items (records / rows) or monetary units. The function returns an object of class \code{jfaSelection} which can be used with associated \code{summary()} and a \code{plot()} methods.
@@ -89,7 +104,7 @@ selection <- function(data, size, units = c("items", "values"),
     stop("cannot take a sample larger than the population when 'replace = FALSE'")
   }
   if (units == "values" && is.null(values)) { # Check if the book values have a valid input
-    stop("'values' is missing for selection")
+    stop("missing value for 'values'")
   }
   if (!is.null(values) && length(values) != 1) { # Check if the book values have a valid input
     stop("'values' must be a single character")
